==> vss-ui-4.141.4.tgz: package/Components/FocusZone/FocusZone.js <==
import * as tslib_1 from "tslib";
import "../../Core/core.scss";
import "../../Common.scss";
import * as React from "react";
import { getRelationship } from "../../Util";
// The FocusZoneContext carries the identifier for the current FocusZone.
export var FocusZoneContext = React.createContext({ focuszoneId: undefined });
var focuszoneId = 1;
var FocusZone = /** @class */ (function (_super) {
    tslib_1.__extends(FocusZone, _super);
    function FocusZone(props) {
        var _this = _super.call(this, props) || this;
        _this.rootElements = [];
        _this.state = {
            focuszoneId: "focuszone-" + focuszoneId++
        };
        return _this;
    }
    FocusZone.prototype.render = function () {
        var _this = this;
        // We need to shim the KeyDown event on each of the children. This allows us to capture
        // the event and process it for focus changes.
        return (React.createElement(React.Fragment, null,
            React.createElement(FocusZoneContext.Provider, { value: this.state }, React.Children.map(this.props.children, function (child, index) {
                if (typeof child === "string" || typeof child === "number") {
                    return child;
                }
                // All direct children MUST be DOM elements.
                if (typeof child.type !== "string") {
                    throw Error("Children of a focus zone MUST be DOM elements");
                }
                // Save the supplied keydown event handler so we can forward the event to it.
                var existingOnKeyDown = child.props.onKeyDown;
                return React.cloneElement(child, Object.assign({ key: index }, child.props, {
                    onKeyDown: function (event) {
                        if (existingOnKeyDown) {
                            existingOnKeyDown(event);
                        }
                        if (!event.defaultPrevented && !_this.props.disabled) {
                            var offset = void 0;
                            switch (event.which) {
                                case 38 /* UpArrow */:
                                    if (_this.props.direction === 2 /* Vertical */) {
                                        offset = -1;
                                    }
                                    break;
                                case 40 /* DownArrow */:
                                    if (_this.props.direction === 2 /* Vertical */) {
                                        offset = 1;
                                    }
                                    break;
                                case 39 /* RightArrow */:
                                    if (_this.props.direction === 1 /* Horizontal */) {
                                        offset = 1;
                                    }
                                    break;
                                case 37 /* LeftArrow */:
                                    if (_this.props.direction === 1 /* Horizontal */) {
                                        offset = -1;
                                    }
                                    break;
                            }
                            if (offset) {
                                _this.focusNextElement(offset);
                                event.preventDefault();
                            }
                        }
                    },
                    ref: function (element) {
                        _this.rootElements[index] = element;
                    }
                }));
            }))));
    };
    FocusZone.prototype.componentDidMount = function () {
        var focusElement;
        // If a defaultActiveElement is supplied we will focus it. It is not required to
        // be member of the focus zone, it can be any element.
        if (this.props.shouldFocusOnMount) {
            if (this.props.defaultActiveElement) {
                focusElement = document.querySelector(this.props.defaultActiveElement);
            }
            else {
                var focusElements = this.getFocusElements();
                if (focusElements.length > 0) {
                    focusElement = focusElements[0];
                }
            }
        }
        if (focusElement) {
            window.setTimeout(function () {
                focusElement.focus();
            }, 0);
        }
    };
    FocusZone.prototype.focusNextElement = function (offset) {
        var focusElements = this.getFocusElements();
        if (focusElements.length > 0) {
            var focusCurrent = document.activeElement;
            // Determine if an element in the focus zone has focus.
            var focusIndex = focusElements.indexOf(focusCurrent);
            // Focus may not be on an element in the zone so we need to
            // figure out which one we are between in this case.
            if (focusIndex === -1) {
                for (var index = 0; index < focusElements.length; index++) {
                    var relationship = getRelationship(focusCurrent, focusElements[index]);
                    if (relationship === 1 /* Before */) {
                        focusIndex = index - (offset > 0 ? 1 : 0);
                        break;
                    }
                    else if (relationship === 3 /* Child */) {
                        focusIndex = index;
                        break;
                    }
                    else if (relationship === 2 /* After */ && index === focusElements.length - 1) {
                        focusIndex = focusElements.length;
                    }
                }
            }
            // Move to the next component in the set of focus zone components.
            focusIndex += offset;
            // If the FocusZone supports circular navigation and we are on the end
            // we will move to the element on the opposite end.
            if (this.props.isCircularNavigation) {
                if (focusIndex < 0) {
                    focusIndex = focusElements.length - 1;
                }
                else if (focusIndex >= focusElements.length) {
                    focusIndex = 0;
                }
            }
            // If we ended up on a focusable element update the focus.
            if (focusIndex > -1 && focusIndex < focusElements.length) {
                focusElements[focusIndex].focus();
            }
        }
    };
    FocusZone.prototype.getFocusElements = function () {
        var focusElements = [];
        for (var _i = 0, _a = this.rootElements; _i < _a.length; _i++) {
            var rootElement = _a[_i];
            var focusChildren = rootElement.querySelectorAll("[data-focuszone=" + this.state.focuszoneId + "]");
            for (var rootIndex = 0; rootIndex < focusChildren.length; rootIndex++) {
                focusElements.push(focusChildren[rootIndex]);
            }
        }
        return focusElements;
    };
    return FocusZone;
}(React.Component));
export { FocusZone };

==> vss-ui-4.142.1.tgz: package/Components/FocusZone/FocusZone.js <==
import * as tslib_1 from "tslib";
import "../../Core/core.scss";
import "../../Common.scss";
import * as React from "react";
import { getRelationship } from "../../Util";
// The FocusZoneContext carries the identifier for the current FocusZone.
export var FocusZoneContext = React.createContext({ focuszoneId: undefined });
var focuszoneId = 1;
var FocusZone = /** @class */ (function (_super) {
    tslib_1.__extends(FocusZone, _super);
    function FocusZone(props) {
        var _this = _super.call(this, props) || this;
        _this.rootElements = [];
        _this.state = {
            focuszoneId: "focuszone-" + focuszoneId++
        };
        return _this;
    }
    FocusZone.prototype.render = function () {
        var _this = this;
        // We need to shim the KeyDown event on each of the children. This allows us to capture
        // the event and process it for focus changes.
        return (React.createElement(React.Fragment, null,
            React.createElement(FocusZoneContext.Provider, { value: this.state }, React.Children.map(this.props.children, function (child, index) {
                if (typeof child === "string" || typeof child === "number") {
                    return child;
                }
                // All direct children MUST be DOM elements.
                if (typeof child.type !== "string") {
                    throw Error("Children of a focus zone MUST be DOM elements");
                }
                // Save the supplied keydown event handler so we can forward the event to it.
                var existingOnKeyDown = child.props.onKeyDown;
                return React.cloneElement(child, Object.assign({ key: index }, child.props, {
                    onKeyDown: function (event) {
                        if (existingOnKeyDown) {
                            existingOnKeyDown(event);
                        }
                        if (!event.defaultPrevented && !_this.props.disabled) {
                            var offset = void 0;
                            switch (event.which) {
                                case 38 /* UpArrow */:
                                    if (_this.props.direction === 2 /* Vertical */) {
                                        offset = -1;
                                    }
                                    break;
                                case 40 /* DownArrow */:
                                    if (_this.props.direction === 2 /* Vertical */) {
                                        offset = 1;
                                    }
                                    break;
                                case 39 /* RightArrow */:
                                    if (_this.props.direction === 1 /* Horizontal */) {
                                        offset = 1;
                                    }
                                    break;
                                case 37 /* LeftArrow */:
                                    if (_this.props.direction === 1 /* Horizontal */) {
                                        offset = -1;
                                    }
                                    break;
                            }
                            if (offset) {
                                _this.focusNextElement(offset);
                                event.preventDefault();
                            }
                        }
                    },
                    ref: function (element) {
                        _this.rootElements[index] = element;
                    }
                }));
            }))));
    };
    FocusZone.prototype.componentDidMount = function () {
        var focusElement;
        // If a defaultActiveElement is supplied we will focus it. It is not required to
        // be member of the focus zone, it can be any element.
        if (this.props.shouldFocusOnMount) {
            var focusElements = this.getFocusElements(this.props.defaultActiveElement);
            if (focusElements.length > 0) {
                focusElement = focusElements[0];
            }
        }
        if (focusElement) {
            focusElement.focus();
        }
    };
    FocusZone.prototype.focusNextElement = function (offset) {
        var focusElements = this.getFocusElements();
        if (focusElements.length > 0) {
            var focusCurrent = document.activeElement;
            // Determine if an element in the focus zone has focus.
            var focusIndex = focusElements.indexOf(focusCurrent);
            // Focus may not be on an element in the zone so we need to
            // figure out which one we are between in this case.
            if (focusIndex === -1) {
                for (var index = 0; index < focusElements.length; index++) {
                    var relationship = getRelationship(focusCurrent, focusElements[index]);
                    if (relationship === 1 /* Before */) {
                        focusIndex = index - (offset > 0 ? 1 : 0);
                        break;
                    }
                    else if (relationship === 3 /* Child */) {
                        focusIndex = index;
                        break;
                    }
                    else if (relationship === 2 /* After */ && index === focusElements.length - 1) {
                        focusIndex = focusElements.length;
                    }
                }
            }
            // Move to the next component in the set of focus zone components.
            focusIndex += offset;
            // If the FocusZone supports circular navigation and we are on the end
            // we will move to the element on the opposite end.
            if (this.props.isCircularNavigation) {
                if (focusIndex < 0) {
                    focusIndex = focusElements.length - 1;
                }
                else if (focusIndex >= focusElements.length) {
                    focusIndex = 0;
                }
            }
            // If we ended up on a focusable element update the focus.
            if (focusIndex > -1 && focusIndex < focusElements.length) {
                focusElements[focusIndex].focus();
            }
        }
    };
    FocusZone.prototype.getFocusElements = function (selector) {
        var focusElements = [];
        for (var _i = 0, _a = this.rootElements; _i < _a.length; _i++) {
            var rootElement = _a[_i];
            var focusChildren = rootElement.querySelectorAll(selector || "[data-focuszone~=" + this.state.focuszoneId + "]");
            for (var rootIndex = 0; rootIndex < focusChildren.length; rootIndex++) {
                focusElements.push(focusChildren[rootIndex]);
            }
        }
        return focusElements;
    };
    return FocusZone;
}(React.Component));
export { FocusZone };
